
// @ts-nocheck
import React from 'react'
import { mdx } from '@mdx-js/react'

/* @jsxRuntime classic */
/* @jsx mdx */

import { MDXScopeProvider } from '@teambit/ui.mdx-scope-context';


const layoutProps = {
  
};
const MDXLayout = "wrapper"
export default function MDXContent({
  components,
  ...props
}) {
  return <MDXLayout {...layoutProps} {...props} components={components} mdxType="MDXLayout">
    <MDXScopeProvider components={{}} mdxType="MDXScopeProvider"><h2>{`How to Render your Component`}</h2>
      <iframe width="560" height="315" src="https://www.youtube.com/embed/so8CcUzTrn4?rel=0" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
      <p>{`Bit supports rendering your component in isolation which works as your local development environment. You can have multiple compositions per component to showcase different use cases, themes etc.`}</p>
      <blockquote>
        <p parentName="blockquote">{`Adding compositions to a component is done by creating a file in the component's directory, using the `}<inlineCode parentName="p">{`*.composition.*`}</inlineCode>{` pattern.`}</p>
      </blockquote>
      <p>{`For example:`}</p>
      <pre><code parentName="pre" {...{
          "className": "language-bash",
          "metastring": "{3}",
          "{3}": true
        }}>{`button
├── button.composition.tsx
├── button.tsx
└── index.ts
`}</code></pre>
      <p>{`You can create various compositions to showcase different usages of your component.`}</p>
      <p>{`Basic Button:`}</p>
      <pre><code parentName="pre" {...{
          "className": "language-js"
        }}>{`import React from 'react';
import { Button } from './button';

export const BasicButton = () => {
  return <Button text="click me" />;
};
`}</code></pre>
      <p>{`Primary Button:`}</p>
      <pre><code parentName="pre" {...{
          "className": "language-js"
        }}>{`import React from 'react';
import { Button } from './button';

export const PrimaryButton = () => {
  return <Button type="primary" text="click me" />;
};
`}</code></pre>
      <p><a parentName="p" {...{
          "href": "https://harmony-docs.bit.dev/aspects/compositions"
        }}>{`Learn more about compositions.`}</a></p></MDXScopeProvider>
    </MDXLayout>;
}

;
MDXContent.isMDXComponent = true;